@@ -37,6 +37,24 @@ sub model_class {
 
 
 
+=head1 ACTIONS
+
+=head2 add_genre
+
+Forward to /genre/add.
+
+For unit testing.
+
+=cut
+sub add_genre : Local {
+    my ($self, $c) = @_;
+
+    $c->forward("/genre/set_crud_controller");
+    $c->forward("/genre/add");
+}
+
+
+
 =head1 SEE ALSO
 
 L<BookShelf>, L<Catalyst::Enzyme::CRUD::Controller>,
