@@ -3,11 +3,12 @@ use base 'Catalyst::Model::CDBI';
 
 use strict;
 use Class::DBI::Pager;
+use Path::Class;
 
 
 
 __PACKAGE__->config(
-    dsn           => 'dbi:SQLite:dbname=db/bookshelf.db',
+    dsn           => 'dbi:SQLite:dbname=' . file(BookShelf->config->{home}, 'db/bookshelf.db'),
     user          => '',
     password      => '',
     options       => {},
